Baseband-tasks: A Package for Radio Baseband Data Reduction
-----------------------------------------------------------

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
   :target: http://www.astropy.org
   :alt: Powered by Astropy Badge

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.3951543.svg
   :target: https://doi.org/10.5281/zenodo.3951543
   :alt: DOI 10.5281/zenodo.3951543

.. image:: https://github.com/mhvk/baseband-tasks/workflows/CI/badge.svg
   :target: https://github.com/mhvk/baseband-tasks/actions
   :alt: Test Status

.. image:: https://codecov.io/gh/mhvk/baseband-tasks/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/mhvk/baseband-tasks
   :alt: Coverage Level

.. image:: https://readthedocs.org/projects/baseband-tasks/badge/?version=latest
   :target: https://baseband-tasks.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

Baseband-tasks is a package for reduction and analysis of radio baseband data.
It relies on `Baseband <https://pypi.org/project/baseband/>`_,
`NumPy <http://www.numpy.org/>`_ and `Astropy <http://www.astropy.org/>`_.

For installation and usage instructions, please see the `online documentation
<https://baseband.readthedocs.io/projects/baseband-tasks/>`_.

If you used this package in your research, please cite it via DOI
`10.5281/zenodo.3951543 <https://doi.org/10.5281/zenodo.3951543>`_.

Contributing
------------

Please open a new issue for bugs, feedback or feature requests.

We welcome code contributions!  To add a contribution, please submit a pull
request.  If you would like assistance in using GitHub or how to begin
modifying Baseband-tasks, please feel free to contact `@mhvk`_ or
`@luojing1211`_.

For more information on how to make code contributions, please see the `Astropy
developer documentation <http://docs.astropy.org/en/stable/index.html#developer-documentation)>`_.

License
-------

Baseband-tasks is licensed under the GNU General Public License v3.0 - see the
``LICENSE`` file.

.. _@mhvk: https://github.com/mhvk
.. _@luojing1211: https://github.com/luojing1211
